aboutsummaryrefslogtreecommitdiff
path: root/pcap-int.h
diff options
context:
space:
mode:
Diffstat (limited to 'pcap-int.h')
-rw-r--r--pcap-int.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/pcap-int.h b/pcap-int.h
index d18dd192..c46c5a51 100644
--- a/pcap-int.h
+++ b/pcap-int.h
@@ -526,11 +526,14 @@ int install_bpf_program(pcap_t *, struct bpf_program *);
int pcap_strcasecmp(const char *, const char *);
/*
* Internal interface for pcap_parsesrcstr with the additional bit of
* information regarding SSL support (rpcap:// vs rpcaps://)
*/
-int pcap_parsesrcstr_ex(const char *source, int *type, char *host, char *port,
- char *name, unsigned char *uses_ssl, char *errbuf);
+int pcap_createsrcstr_ex(char *, int, const char *, const char *,
+ const char *, unsigned char, char *);
+int pcap_parsesrcstr_ex(const char *, int *, char *, char *,
+ char *, unsigned char *, char *);
#ifdef YYDEBUG
extern int pcap_debug;
@@ -526,11 +526,14 @@ int install_bpf_program(pcap_t *, struct bpf_program *);
int pcap_strcasecmp(const char *, const char *);
/*
- * Internal interface for pcap_parsesrcstr with the additional bit of
- * information regarding SSL support (rpcap:// vs rpcaps://)
+ * Internal interfaces for pcap_createsrcstr and pcap_parsesrcstr with
+ * the additional bit of information regarding SSL support (rpcap:// vs.
+ * rpcaps://).
*/